<?PHP // $Id$ 
      // pix.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['angry'] = 'Vihainen';
$string['approve'] = 'Hyvksyv';
$string['biggrin'] = 'Iso irvistys';
$string['blackeye'] = 'Musta silm';
$string['blush'] = 'Punastua';
$string['clown'] = 'Pelle';
$string['cool'] = 'Tyyliks';
$string['dead'] = 'Kuollut';
$string['evil'] = 'Paha';
$string['kiss'] = 'Suukko';
$string['mixed'] = 'Sekaisin';
$string['sad'] = 'Surullinen';
$string['shy'] = 'Ujo';
$string['sleepy'] = 'Vsynyt';
$string['smiley'] = 'Hymy';
$string['surprise'] = 'Yllttynyt';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Suomi';
$string['thoughtful'] = 'Ajattelevainen';
$string['tongueout'] = 'Nytt kielt';
$string['wideeyes'] = 'Silmt suurina';
$string['wink'] = 'Nikkaa';

?>
